Ns-usbloader

developersu developersu
Dépôt créer le : 10/02/2019
Release du : 10/03/2026 v7.3
Forks: 139 Watcher: 0 2204
Choisir une liste...
FR

NS-USBloader

License Releases LatestVer status-badge Packaging status

NS-USBloader est:

  • Un installateur côté PC pourHuntereb/Awoo-Installer/ autres installateurs compatibles (USB et réseau pris en charge) etXorTroll/Goldleaf(USB) installateur NSP. Alternative au défautusb install pc.py,distant installer pc.py,OrTree/Quark.
  • Outil de charge utile RCM qui fonctionne sur Windows, macOS (Intel et Apple Silicon) et Linux (x86, amd64 et Raspberry Pi ARM).
  • C'est un outil pour créer des fichiers divisés !
  • Vous pouvez également l'utiliser pour fusionner des fichiers séparés en un seul :)

Click here for Android version ;)

Avec l'interface utilisateur et les cookies. Fonctionne sous Windows, macOS et Linux.

Restez en contact :

→ Independent source code storage

→ Mirror, issues tracker, place to send PRs

→ Nightly builds

Support/Donate

Parfois j'ajoute de nouveaux messages sur ce projeton my blog page.

screenshot screenshot
screenshot screenshot
screenshot

Licence

GNU General Public License version 3, ou (à votre choix) toute version ultérieure.

Bibliothèques et ressources utilisées

Liste des contributeurs de code impressionnants, des traducteurs et d'autres grandes personnes!

Exigences du système

  • JDK 17 pour macOS et Linux
  • libusb, si vous avez un Mac avec Apple Silicon (installer viabrew install libusb)

Versions Goldleaf prises en charge

Version Goldleaf Le présent règlement entre en vigueur le vingtième jour suivant celui de sa publication au Journal officiel de l'Union européenne. - v0.5.2, v0.8+ Aucun Voir la note de bas de page. V0,7 – 0,73 V0.8 - 0.9 V0.10 - 1.0.0. v1.1.0 - 1.1.1. L'objectif de l'étude est d'évaluer les effets de l'utilisation de l'énergie sur l'environnement

où '+' signifie 'toute prochaine version NS-USBloader'.

Prise en charge de l'installateur Awoo et des applications compatibles

Awoo Installer utilise le même ensemble de commandes (ou 'protocol') pourAdubbz/Tinfoil.

Beaucoup d'autres forks/apps utilisent le même jeu de commandes. Pour arrêter de spéculer sur le nom qu'il est maintenant appelé 'Awoo'. Ça s'appelait "TinFoil". Plus jamais.

Utilisation

Linux :

  1. Installez JRE/JDK 8u60 ou plus (openJDK est bon. Oracle est aussi bon). JavaFX n'est pas nécessaire (il est intégré).

  2. root # java -jar /path/to/NS-USBloader.jar

  3. Optionnel : ajouter l'utilisateur aux règles 'udev' pour utiliser NS not-from-root-count

root # vim /etc/udev/rules.d/99-NS.rules
SUBSYSTEM=="usb", ATTRS{idVendor}=="057e", ATTRS{idProduct}=="3000", MODE="0666"
root # udevadm control --reload-rules && udevadm trigger
  1. Pour la partie MCR
root # vim /etc/udev/rules.d/99-NS-RCM.rules
SUBSYSTEM=="usb", ATTRS{idVendor}=="0955", ATTRS{idProduct}=="7321", MODE="0666"
root # udevadm control --reload-rules && udevadm trigger
  1. Pour HiDPI utiliser l'échelle commejava -Dglass.gtk.uiScale=150% -jar application.jar

Raspberry Pi

  1. Installez JDK :sudo apt install default-jdk

  2. Pour l'interface utilisateur installer JavaFX :sudo apt install openjfx

  3. Voir les étapes 3 et 4 de la section 'Linux' pour mettre à jour 'udev'.

macOS

Double-cliquez sur le fichier .jar téléchargé. Suivez les instructions. Ou voir section "Linux".

Définir les paramètres de sécurité et de confidentialité si nécessaire.

Remarque : JDK 19 est recommandé pour l'utilisation sur macOS. Des problèmes sont déjà signalés par les utilisateurs sur Mac avec JDK 14.

macOS sur Apple Silicon (ARM)

Télécharger l'application avec-m1.jarpostfixe.

Installez manuellement libusb avec Homebrew en exécutantbrew install libusbdans votre terminal.

Windows & #160;:

  • Une fois l'application ouverte, cliquez sur l'icône 'Gear'.
  • Cliquez sur 'Télécharger et installer les pilotes'
  • Installer les pilotes

Et comment l'utiliser ?

La première chose que vous devriez le faire installer Awoo (Huntereb) ou de feuilles d'or (XorTroll) sur votre NS.

Jetez un oeil sur l'application, trouvez où est l'option à installer à partir d'USB et/ou réseau. Peut-être (très vieux)this article (about TinFoil)sera utile.

En détail

Il y a trois onglets. Le premier est principal.

Onglet "Gamepad". .

En haut de votre sélection à partir de l'application déroulante et du protocole que vous allez utiliser. Pour Goldleaf seulement USB est disponible. L'icône de la lampe est synonyme de changement de thème (lumière ou sombre).

Ensuite, vous pouvez glisser-n-déposer des fichiers (dossiers de fichiers séparés aka) vers l'application ou utiliser le bouton 'Sélectionner des fichiers NSP'. Sélection multiple pour les fichiers disponibles. Cliquez à nouveau et sélectionnez les fichiers d'un autre dossier que vous voulez, il sera ajouté dans la table.

Tableau.

Vous pouvez y sélectionner la case à cocher pour les fichiers qui seront envoyés à l'application (AW/GL). ~~Puisque Goldleaf v0.5 vous permet une seule transmission de fichier par temps, un seul fichier est disponible pour la sélection.~~

Aussi, vous pouvez utiliser l'espace pour sélectionner/désélectionner les fichiers et le bouton 'supprimer' pour supprimer. En cliquant-droit sur la souris, vous pouvez voir le menu contextuel où vous pouvez supprimer un OU tous les éléments de la table.

Pour Goldleaf v0.6.1 et NS-USBloader v0.6 (et plus) vous devrez utiliser 'Explorer le contenu' -> 'Remote PC (via USB)' Vous verrez deux disques HOME:/ et VIRT:/. Le premier lecteur pointe vers votre dossier personnel. La deuxième est le reflet de ce que vous avez ajouté à la table (first application tab). Aussi VIRT:/ drive ont des fonctionnalités limitées par rapport à HOME:/. Par exemple, vous ne pouvez pas écrire des fichiers sur ce disque puisque ce n'est pas un disque. Mais ne vous inquiétez pas, il ne fera aucun impact sur Goldleaf ou votre NS si vous essayez.

Aussi, pour les fichiers d'écriture Goldleaf (de NS à PC): Vous devez 'Stop exécution' correctement avant d'accéder aux fichiers transférés de GL. Habituellement, vous devez attendre 5sec ou moins. Il garantira que vos fichiers correctement écrits sur PC.

Rubrique « RCM »

Sur cet onglet, vous pouvez sélectionner le chargeur comme Hekate ou LockPick RCM et l'envoyer à NS. Prise en charge par Drag-n-drop. Certaines validations in-app pour la charge utile ont également lieu ;)

Onglet 'Dossier avec flèches et zéros'

Sur cet onglet, vous pouvez diviser et fusionner des fichiers. Sélectionnez 'Split' ou 'Merge' et divisez (ou fusionnez). BTW Drag-n-drop pris en charge.

"Gears". .

Ici vous pouvez configurer les paramètres pour la transmission de fichiers réseau. D'habitude, tu ne devrais rien changer. Mais c'est toi le hacker cool, vas-y ! L'option la plus intéressante ici est 'Ne pas servir les demandes'. L'architecture de la partie NET d'Awoo fonctionne de manière intéressante. Lorsque vous sélectionnez dans le transfert réseau NSP d'Awoo, l'application attendra au port 2000 les informations sur l'endroit où elle devrait prendre des fichiers. Comme '192.168.1.5:6060/mon fichier.nsp'. Habituellement NS-USBloader sert les requêtes en implémentant un serveur HTTP simplifié et en le faisant monter, etc. Mais si cette option est sélectionnée, vous pouvez définir le chemin vers l'emplacement distant des fichiers. Par exemple si vous définissez dans les paramètres '192.168.4.2:80/ROMS/NS/' et ajoutez dans le fichier de table 'mon fichier.nsp', NS-USBloader dira simplement à Awoo "Hey, allez prendre des fichiers de '192.168.4.2:80/ROMS/NS/my%20file.nsp'". Bien sûr, vous devez apporter l'hôte '192.168.4.2' et rendre le fichier accessible à partir de cette adresse (aller simplement installer nginx). Comme je l'ai dit, cette fonctionnalité est intéressante, mais je suppose qu'elle ne sera pas populaire.

Vous pouvez également :

  • Définir 'Vérifier automatiquement les mises à jour' pour vérifier les mises à jour lorsque l'application démarre, ou cliquez sur le bouton pour vérifier si la nouvelle version est publiée immédiatement.
  • Définir 'Afficher seulement *.nsp dans Goldleaf' pour filtrer tous les fichiers affichés sur HOME:/ drive. Donc seuls les fichiers NSP apparaîtront.

"Dialogue avec trois points". .

C'est là que tous les journaux sont tombés. Verbeux informations sur les transmissions vient ici.

CLI (interface de ligne de commande)

Pour obtenir de l'aide$ java -jar ns-usbloader-4.0.jar --help

 -c,--clean                      Remove/reset settings and exit
 -g,--Goldleaf <...>             Install via Goldleaf mode. Check '-g help' for information.
 -h,--help                       Show this help
 -m,--merge <...>                Merge files. Check '-m help' for information.
 -n,--tfn <...>                  Install via Awoo Network mode. Check '-n help' for information.
 -r,--rcm <[PATH/]payload.bin>   Send payload
 -s,--split <...>                Split files. Check '-s help' for information.
 -t,--tinfoil <FILE...>          Install via Awoo USB mode.
 -v,--version                    Show application version

Pour des commandes plus complexes aider à utiliser l'aide argument après la touche de poings. Par exemple:

$ java -jar ns-usbloader-4.0.jar -n help

Usage:
        ns-usbloader -n nsip=<arg1> [hostip=<arg2>] FILE1 ...
        ns-usbloader --tfn nsip=<arg1> [hostip=<arg2>] FILE1 ...

Options:
        nsip=<ip>               Define NS IP address (mandatory)
        hostip=<ip[:port]>      Define this host IP address. Will be obtained automatically if not set.

Exemples d'utilisation :

Send RCM payload:
$ java -jar ns-usbloader-4.0.jar -r C:\Users\Superhero\hekate.bin
Send files to Awoo Installer via Net-install: 
$ java -jar ns-usbloader-4.0.jar -n nsip=192.168.0.1 ./file.nsz ./file.nsp ~/*.xci
Send files to Goldleaf v0.8:
$ java -jar ns-usbloader-4.0.jar -g ver=v0.8 ./*
Split files:
$ java -jar ns-usbloader-4.0.jar -s /tmp/ ~/*.nsp
Merge files:
$ java -jar ns-usbloader-4.0.jar -m /tmp/ ~/*.nsp

Autres notes

'Status' = 'Uploaded' qui apparaît dans la table ne signifie pas que le fichier a été installé. Cela signifie qu'il a été envoyé à NS sans aucun problème! C'est ça, cette application. La manipulation de l'installation réussie/échec est un objectif de l'autre application latérale: Awoo/Awoo-like ou Goldleaf. Et ils ne fournissent aucune interface de rétroaction pour que je ne puisse pas détecter le succès/échec.

Qu'est-ce que c'est que ce pot '-légace'?!

JAR avec aucun postfixerecommandé pour les utilisateurs de Windows, Linux et macOS qui utilisent Mojave ou des versions ultérieures.

JAR avec postfixe '-legacy'est pour les utilisateurs macOS qui utilisent encore les versions OS X avant (!) Mojave. (Il fonctionne aussi pour Linux et Windows, mais parfois il ne fonctionne pas pour Windows et je ne sais pas pourquoi).

Nous avons cette situation en raison d'un comportement bizarre dans la bibliothèque usb4java utilisée dans cette application pour les interactions USB. Dans '-legacy' c'est v1.2.0 et dans 'normal' c'est v1.3.0

Traducteurs !

Si vous voulez voir cette application traduite dans votre langue, allez chercherthis fileet la traduire.

Si vous êtes familier avec la demande de tirage, allez-y et créez-la! Pas de soucis si vous ne l'êtes pas. Il suffit de télécharger quelque part (comme petebin/google drive/tout le reste).Create new issueet poster un lien. Je vais le prendre et ajouter.

Pour convertir des fichiers de n'importe quelle locale en format lisible (et vise-versa) vous pouvez utiliser ce sitehttps://itpro.cz/juniconv/

Soutenez cette application

Si vous aimez cette application, donnez juste une étoile (@ GitHub).

C'est un projet non commercial.

Merci !

Appréciez l'aide et le soutien des deuxVitaliyetKonstantinSans toi, toute cette magie n'aurait pas eu lieu.

Contributeurs GitHub

andercard0
andercard0
1 contributions
R-YaTian
R-YaTian
7 contributions
DDinghoya
DDinghoya
1 contributions
kuragehimekurara1
kuragehimekurara1
4 contributions
developersu
developersu
28 contributions
justindhillon
justindhillon
13 contributions
exiori
exiori
12 contributions
wolfposd
wolfposd
6 contributions
pnghai
pnghai
2 contributions
unbranched
unbranched
2 contributions
requinDr
requinDr
2 contributions
calini
calini
2 contributions
peacepenguin
peacepenguin
2 contributions
Erimsaholut
Erimsaholut
1 contributions
davidebeatrici
davidebeatrici
1 contributions
htynkn
htynkn
3 contributions
kevinrieger
kevinrieger
1 contributions
qazrfv1234
qazrfv1234
1 contributions